==> ejc-probuilddiary-api-3.0.0-20220916.063707-4-sources.jar: com/ejianc/business/probuilddiary/construct/vo/ConstructAreaDetailVO.java <==
package com.ejianc.business.probuilddiary.construct.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.ejianc.business.probuilddiary.construct.utils.ITreeNodeB;

import java.util.ArrayList;
import java.util.List;

/**
 * 施工区域 详情表
 * 
 * @author generator
 * 
 */
public class ConstructAreaDetailVO extends BaseVO implements ITreeNodeB{
    private static final long serialVersionUID = 1L;
    private Long detailId;//清单ID
    private Long dutyId; // 责任人id
    private String dutyName; // 责任人名称
    private String dutyCode; // 责任人编码
    private String detailStatus; // 状态
    private String constructionRegion; // 施工区域
    private Long parentId;//父ID
    private String treeIndex;//序号
    private String tid;
    private String tpid;
    private List<ITreeNodeB> children;

    public Long getDetailId() {
        return detailId;
    }

    public void setDetailId(Long detailId) {
        this.detailId = detailId;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public void setChildren(List<ITreeNodeB> children) {
        this.children = children;
    }

    @Override
    public Long getNodeID() {
        return getId();
    }

    @Override
    public Long getParentID() {
        return parentId;
    }

    @Override
    public List<ITreeNodeB> getChildren() {
        if (children == null) {
            children = new ArrayList<>();
        }
        return children;
    }


    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public String getTreeIndex() {
        return treeIndex;
    }

    public void setTreeIndex(String treeIndex) {
        this.treeIndex = treeIndex;
    }

    public Long getDutyId() {
        return dutyId;
    }
    @ReferDeserialTransfer
    public void setDutyId(Long dutyId) {
        this.dutyId = dutyId;
    }
    public String getDutyName() {
        return dutyName;
    }

    public void setDutyName(String dutyName) {
        this.dutyName = dutyName;
    }
    public String getDutyCode() {
        return dutyCode;
    }

    public void setDutyCode(String dutyCode) {
        this.dutyCode = dutyCode;
    }
    public String getDetailStatus() {
        return detailStatus;
    }

    public void setDetailStatus(String detailStatus) {
        this.detailStatus = detailStatus;
    }
    public String getConstructionRegion() {
        return constructionRegion;
    }

    public void setConstructionRegion(String constructionRegion) {
        this.constructionRegion = constructionRegion;
    }
    
}

==> ejc-probuilddiary-api-3.0.0-20220919.091701-11-sources.jar: com/ejianc/business/probuilddiary/construct/vo/ConstructAreaDetailVO.java <==
package com.ejianc.business.probuilddiary.construct.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.ejianc.business.probuilddiary.construct.utils.ITreeNodeB;

import java.util.ArrayList;
import java.util.List;

/**
 * 施工区域 详情表
 * 
 * @author generator
 * 
 */
public class ConstructAreaDetailVO extends BaseVO implements ITreeNodeB{
    private static final long serialVersionUID = 1L;
    private Long detailId;//清单ID
    private Long dutyId; // 责任人id
    private String dutyName; // 责任人名称
    private String dutyCode; // 责任人编码
    private String detailStatus; // 状态 0停用 1 启用
    private String constructionRegion; // 施工区域
    private Long parentId;//父ID
    private String treeIndex;//序号
    private String tid;
    private String tpid;
    private String detailBillState;//单据状态
    private List<ITreeNodeB> children;

    public String getDetailBillState() {
        return detailBillState;
    }

    public void setDetailBillState(String detailBillState) {
        this.detailBillState = detailBillState;
    }

    public Long getDetailId() {
        return detailId;
    }

    public void setDetailId(Long detailId) {
        this.detailId = detailId;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public void setChildren(List<ITreeNodeB> children) {
        this.children = children;
    }

    @Override
    public Long getNodeID() {
        return getId();
    }

    @Override
    public Long getParentID() {
        return parentId;
    }

    @Override
    public List<ITreeNodeB> getChildren() {
        if (children == null) {
            children = new ArrayList<>();
        }
        return children;
    }


    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public String getTreeIndex() {
        return treeIndex;
    }

    public void setTreeIndex(String treeIndex) {
        this.treeIndex = treeIndex;
    }

    public Long getDutyId() {
        return dutyId;
    }
    @ReferDeserialTransfer
    public void setDutyId(Long dutyId) {
        this.dutyId = dutyId;
    }
    public String getDutyName() {
        return dutyName;
    }

    public void setDutyName(String dutyName) {
        this.dutyName = dutyName;
    }
    public String getDutyCode() {
        return dutyCode;
    }

    public void setDutyCode(String dutyCode) {
        this.dutyCode = dutyCode;
    }
    public String getDetailStatus() {
        return detailStatus;
    }

    public void setDetailStatus(String detailStatus) {
        this.detailStatus = detailStatus;
    }
    public String getConstructionRegion() {
        return constructionRegion;
    }

    public void setConstructionRegion(String constructionRegion) {
        this.constructionRegion = constructionRegion;
    }
    
}
